@@ -68,6 +68,17 @@ def load_dataset_8ch():
     d.burst_search(L=10, m=10, F=7)
     return d
 
+def load_fake_pax():
+    fn = "0023uLRpitc_NTP_20dT_0.5GndCl.hdf5"
+    fname = DATASETS_DIR + fn
+    d = loader.photon_hdf5(fname)
+    d.add(ALEX=False, meas_type='PAX')
+    loader.alex_apply_period(d)
+    d.calc_bg(bg.exp_fit, time_s=30, tail_min_us='auto')
+    d.burst_search(L=10, m=10, F=6, pax=True)
+    return d
+
+
 @pytest.fixture(scope="module", params=[
                                     load_dataset_1ch,
                                     load_dataset_8ch,
@@ -112,7 +123,6 @@ def list_array_allclose(list1, list2):
 # Test functions
 #
 
-
 def test_bg_compatlayer_for_obsolete_attrs():
     d = load_dataset_1ch(process=False)
     attrs = ('bg_dd', 'bg_ad', 'bg_da', 'bg_aa',
@@ -165,6 +175,7 @@ def test_time_min_max():
     assert d.time_max == d.mburst[0].stop[-1] * d.clk_p
     assert d.time_min == d.mburst[0].start[0] * d.clk_p
 
+
 def test_time_min_max_multispot(data_8ch):
     """Test time_min and time_max for multi-spot data."""
     d = data_8ch
@@ -172,6 +183,112 @@ def test_time_min_max_multispot(data_8ch):
     assert d.time_min == min(t[0] for t in d.ph_times_m) * d.clk_p
 
 
+def test_aex_dex_ratio(data_1ch):
+    """Test methods computing relative D and A alternation periods durations.
+    """
+    d = data_1ch
+    Dx, Ax = d.D_ON, d.A_ON
+    aex_fraction = d._aex_fraction
+    a2 = (Ax[1] - Ax[0]) / (Ax[1] - Ax[0] + Dx[1] - Dx[0])
+    assert aex_fraction == a2
+    aex_dex_ratio = d._aex_dex_ratio
+    r2 = (Ax[1] - Ax[0]) / (Dx[1] - Dx[0])
+    assert aex_dex_ratio == r2
+    assert (aex_fraction / (1 - aex_fraction)) == aex_dex_ratio
+    assert (1 - aex_fraction) == 1 / (1 + aex_dex_ratio)
+
+
+def test_burst_size_pax():
+    d = load_fake_pax()
+    aex_dex_ratio = d._aex_dex_ratio
+    nd, na = d.nd[0], d.na[0]
+    nda, naa = d.nda[0], d.naa[0]
+    naa_aexonly = naa - d.nar[0] * aex_dex_ratio
+
+    # Test burst size during Dex
+    b1 = d.burst_sizes_pax_ich(ph_sel=Ph_sel(Dex='DAem'))
+    b2 = d.burst_sizes_ich(add_naa=False)
+    b3 = nd + na
+    assert (b1 == b2).all()
+    assert (b1 == b3).all()
+
+    # Test burst size during Dex + AexAem
+    b1 = d.burst_sizes_pax_ich(ph_sel=Ph_sel(Dex='DAem', Aex='Aem'),
+                               naa_aexonly=True)
+    b2 = d.burst_sizes_ich(add_naa=True)
+    b3 = nd + na + naa_aexonly
+    assert (b1 == b2).all()
+    assert (b1 == b3).all()
+
+    # Test burst size during AexAem
+    b1 = d.burst_sizes_pax_ich(ph_sel=Ph_sel(Dex=None, Aex='Aem'),
+                               naa_aexonly=True)
+    b2 = naa_aexonly
+    assert (b1 == b2).all()
+
+    # Test all-ph size with no corrections
+    b1 = d.burst_sizes_pax_ich(ph_sel=Ph_sel('all'))
+    b2 = nd + na + nda + naa
+    assert np.allclose(b1, b2)
+
+    # Test all-ph size with all corrections
+    b1 = d.burst_sizes_pax_ich(ph_sel=Ph_sel('all'),
+                               na_comp=True, naa_comp=True, naa_aexonly=True)
+    b2 = (nd + na * (1 + aex_dex_ratio) + nda +
+          naa_aexonly * (1 + aex_dex_ratio))
+    assert np.allclose(b1, b2)
+
+    # Test all-ph size with only na_comp
+    b1 = d.burst_sizes_pax_ich(ph_sel=Ph_sel('all'), na_comp=True)
+    b2 = (nd + na * (1 + aex_dex_ratio) + nda + naa)
+    assert np.allclose(b1, b2)
+
+    # Test all-ph size with na_comp + naa_aexonly
+    b1 = d.burst_sizes_pax_ich(ph_sel=Ph_sel('all'), na_comp=True,
+                               naa_aexonly=True)
+    b2 = (nd + na * (1 + aex_dex_ratio) + nda + naa_aexonly)
+    assert np.allclose(b1, b2)
+
+    # Test add_aex with duty-cycle correction, gamma, beta
+    gamma = 0.7
+    beta = 0.85
+    b1 = d.burst_sizes_pax_ich(ph_sel=Ph_sel('all'),
+                               na_comp=True, naa_comp=True, naa_aexonly=True,
+                               gamma=gamma, beta=beta, donor_ref=True)
+    b2 = d.burst_sizes_pax_ich(ph_sel=Ph_sel('all'),
+                               na_comp=True, naa_comp=True, naa_aexonly=True,
+                               gamma=gamma, beta=beta, donor_ref=False)
+    b3 = (gamma * (nd + nda) + na * (1 + aex_dex_ratio) +
+          naa_aexonly * (1 + aex_dex_ratio) / beta)
+    assert np.allclose(b1 * gamma, b2)
+    assert np.allclose(b2, b3)
+
+    b1 = d.burst_sizes_pax_ich(ph_sel=Ph_sel(Dex='DAem', Aex='Aem'),
+                               naa_aexonly=True,
+                               gamma=gamma, beta=beta, donor_ref=False)
+    b2 = d.burst_sizes_ich(add_naa=True,
+                           gamma=gamma, beta=beta, donor_ref=False)
+    assert np.allclose(b1, b2)
+
+    d.leakage = 0.1
+    nd, na = d.nd[0], d.na[0]
+    nda, naa = d.nda[0], d.naa[0]
+    naa_aexonly = naa - d.nar[0] * aex_dex_ratio
+
+    # Test add_aex with duty-cycle correction, gamma, beta
+    gamma = 0.7
+    beta = 0.85
+    b1 = d.burst_sizes_pax_ich(ph_sel=Ph_sel('all'),
+                               na_comp=True, naa_comp=True, naa_aexonly=True,
+                               gamma=gamma, beta=beta, donor_ref=True)
+    b2 = d.burst_sizes_pax_ich(ph_sel=Ph_sel('all'),
+                               na_comp=True, naa_comp=True, naa_aexonly=True,
+                               gamma=gamma, beta=beta, donor_ref=False)
+    b3 = (gamma * (nd + nda) + na * (1 + aex_dex_ratio) +
+          naa_aexonly * (1 + aex_dex_ratio) / beta)
+    assert np.allclose(b1 * gamma, b2)
+    assert np.allclose(b2, b3)
+
 def test_bg_calc(data):
     """Smoke test bg_calc() and test deletion of bg fields.
     """
@@ -194,7 +311,7 @@ def test_bg_calc(data):
 
 def test_ph_streams(data):
     sel = [Ph_sel('all'), Ph_sel(Dex='Dem'), Ph_sel(Dex='Aem')]
-    if data.ALEX:
+    if data.alternated:
         sel.extend([Ph_sel(Aex='Aem'), Ph_sel(Aex='Dem')])
     for s in sel:
         assert s in data.ph_streams
@@ -208,7 +325,7 @@ def test_bg_from(data):
         bg = d.bg_from(ph_sel=sel)
         assert list_array_equal(bg, d.bg[sel])
 
-    if not data.ALEX:
+    if not (data.alternated):
         assert list_array_equal(d.bg_from(Ph_sel('all')),
                                 d.bg_from(Ph_sel(Dex='DAem')))
         return
@@ -248,18 +365,18 @@ def test_iter_ph_times(data):
     assert list_array_equal(d.ph_times_m, d.iter_ph_times())
 
     for ich, ph in enumerate(d.iter_ph_times(Ph_sel(Dex='Dem'))):
-        if d.ALEX:
+        if d.alternated:
             assert (ph == d.ph_times_m[ich][d.D_em[ich] * d.D_ex[ich]]).all()
         else:
-            assert (ph == d.ph_times_m[ich][-d.A_em[ich]]).all()
+            assert (ph == d.ph_times_m[ich][~d.A_em[ich]]).all()
 
     for ich, ph in enumerate(d.iter_ph_times(Ph_sel(Dex='Aem'))):
-        if d.ALEX:
+        if d.alternated:
             assert (ph == d.ph_times_m[ich][d.A_em[ich] * d.D_ex[ich]]).all()
         else:
             assert (ph == d.ph_times_m[ich][d.A_em[ich]]).all()
 
-    if d.ALEX:
+    if d.alternated:
         for ich, ph in enumerate(d.iter_ph_times(Ph_sel(Aex='Dem'))):
             assert (ph == d.ph_times_m[ich][d.D_em[ich] * d.A_ex[ich]]).all()
         for ich, ph in enumerate(d.iter_ph_times(Ph_sel(Aex='Aem'))):
@@ -283,11 +400,13 @@ def test_iter_ph_times(data):
         assert list_array_equal(d.iter_ph_times(),
                                 d.iter_ph_times(Ph_sel(Dex='DAem')))
 
+
 def test_get_ph_times_period(data):
     for ich in range(data.nch):
         data.get_ph_times_period(0, ich=ich)
         data.get_ph_times_period(0, ich=ich, ph_sel=Ph_sel(Dex='Dem'))
 
+
 def test_iter_ph_times_period(data):
     d = data
     for ich in range(data.nch):
@@ -304,6 +423,7 @@ def test_iter_ph_times_period(data):
             ph_period_test = ph_period_test[mask[istart : iend + 1]]
             assert (ph_period == ph_period_test).all()
 
+
 def test_burst_search_py_cy(data):
     """Test python and cython burst search with background-dependent threshold.
     """
@@ -320,6 +440,7 @@ def test_burst_search_py_cy(data):
     assert np.all(num_bursts1 == data.num_bursts)
     assert mburst1 == data.mburst
 
+
 def test_burst_search_constant_rates(data):
     """Test python and cython burst search with constant threshold."""
     data.burst_search(min_rate_cps=50e3, pure_python=True)
@@ -331,6 +452,7 @@ def test_burst_search_constant_rates(data):
     assert np.all(num_bursts1 == data.num_bursts)
     assert mburst1 == data.mburst
 
+
 def test_burst_search_L(data):
     """Test burst search with different L arguments."""
     data.burst_search(L=10)
@@ -342,51 +464,67 @@ def test_burst_search_L(data):
         assert (bursts.counts >= 30).all()
     assert np.all(num_bursts1 > data.num_bursts)
 
+
 def test_burst_search_with_no_bursts(data):
     """Smoke test burst search when some periods have no bursts."""
     # F=600 results in periods with no bursts for the us-ALEX measurement
     # and in no bursts at all for the multi-spot measurements
     data.burst_search(m=10, F=600)
+    data.fuse_bursts(ms=1)
+
 
 if has_matplotlib:
     def test_stale_fitter_after_burst_search(data):
         """Test that E/S_fitter attributes are deleted on burst search."""
         data.burst_search(L=10, m=10, F=7, ph_sel=Ph_sel(Dex='Dem'))
         bplt.dplot(data, bplt.hist_fret)  # create E_fitter attribute
-        if data.ALEX:
+        if data.alternated:
             bplt.dplot(data, bplt.hist_S)  # create S_fitter attribute
 
         data.burst_search(L=10, m=10, F=7, ph_sel=Ph_sel(Dex='Aem'))
         assert not hasattr(data, 'E_fitter')
-        if data.ALEX:
+        if data.alternated:
             assert not hasattr(data, 'S_fitter')
 
         bplt.dplot(data, bplt.hist_fret)  # create E_fitter attribute
-        if data.ALEX:
+        if data.alternated:
             bplt.dplot(data, bplt.hist_S)  # create S_fitter attribute
 
         data.calc_fret()
         assert not hasattr(data, 'E_fitter')
-        if data.ALEX:
+        if data.alternated:
             assert not hasattr(data, 'S_fitter')
 
+
 def test_burst_search(data):
     """Smoke test and bg_bs check."""
     streams = [Ph_sel(Dex='Dem'), Ph_sel(Dex='Aem')]
-    if data.ALEX:
+    if data.alternated:
         streams.extend([Ph_sel(Dex='Aem', Aex='Aem'), Ph_sel(Dex='DAem')])
     for sel in streams:
         data.burst_search(L=10, m=10, F=7, ph_sel=sel)
         assert list_equal(data.bg_bs, data.bg_from(sel))
 
-    if data.ALEX:
+    if data.alternated:
         data.burst_search(m=10, F=7, ph_sel=Ph_sel(Dex='DAem'), compact=True)
     data.burst_search(L=10, m=10, F=7)
 
+
 def test_burst_search_and_gate(data_1ch):
     """Test consistency of burst search and gate."""
     d = data_1ch
-    assert d.ALEX
+    assert d.alternated
+
+    # Smoke tests
+    bext.burst_search_and_gate(d, F=(6, 8))
+    bext.burst_search_and_gate(d, m=(12, 8))
+    bext.burst_search_and_gate(d, min_rate_cps=(60e3, 40e3))
+    if d.nch > 1:
+        mr1 = 35e3 + np.arange(d.nch) * 1e3
+        mr2 = 30e3 + np.arange(d.nch) * 1e3
+        bext.burst_search_and_gate(d, min_rate_cps=(mr1, mr2))
+
+    # Consistency test
     d_dex = d.copy()
     d_dex.burst_search(ph_sel=Ph_sel(Dex='DAem'))
     d_aex = d.copy()
@@ -399,36 +537,44 @@ def test_burst_search_and_gate(data_1ch):
         ph_b_mask_and = bl.ph_in_bursts_mask(ph.size, bursts_and)
         assert (ph_b_mask_and == ph_b_mask_dex * ph_b_mask_aex).all()
 
+
 def test_mch_count_ph_num_py_c(data):
     na_py = bl.bslib.mch_count_ph_in_bursts_py(data.mburst, data.A_em)
     na_c = bl.bslib.mch_count_ph_in_bursts_c(data.mburst, data.A_em)
     assert list_array_equal(na_py, na_c)
     assert na_py[0].dtype == np.float64
 
+
 def test_burst_sizes(data):
     """Test for .burst_sizes_ich() and burst_sizes()"""
+    d = data
     # Smoke test
     plain_sizes = data.burst_sizes()
     assert len(plain_sizes) == data.nch
     # Test gamma and donor_ref arguments
-    bs1 = data.burst_sizes_ich(gamma=0.5, donor_ref=True)
-    bs2 = data.burst_sizes_ich(gamma=0.5, donor_ref=False)
-    assert np.allclose(bs1, bs2 / 0.5)
+    gamma = 0.5
+    beta = 0.7
+    bs1 = data.burst_sizes_ich(gamma=gamma, donor_ref=True)
+    bs2 = data.burst_sizes_ich(gamma=gamma, donor_ref=False)
+    assert np.allclose(bs1, bs2 / gamma)
     # Test add_naa
-    if data.ALEX:
-        bs_no_naa = data.burst_sizes_ich(add_naa=False)
-        bs_naa = data.burst_sizes_ich(add_naa=True)
-        assert np.allclose(bs_no_naa + data.naa_, bs_naa)
+    nd, na = d.nd[0], d.na[0]
+    assert np.allclose(bs2, gamma * nd + na)
+    if data.alternated:
+        naa = d.naa[0]
+        bs_no_naa = d.burst_sizes_ich(add_naa=False)
+        bs_naa = d.burst_sizes_ich(add_naa=True)
+        assert np.allclose(bs_no_naa + data.naa[0], bs_naa)
+        assert np.allclose(nd + na + naa, bs_naa)
 
         # Test beta and donor_ref arguments with gamma=1
-        naa1 = data.get_naa_corrected(beta=0.8, donor_ref=True)
-        naa2 = data.get_naa_corrected(beta=0.8, donor_ref=False)
-        assert np.allclose(naa1, naa2)
+        kws = dict(add_naa=True, gamma=gamma, beta=beta)
+        b1 = d.burst_sizes_ich(donor_ref=True, **kws)
+        b2 = d.burst_sizes_ich(donor_ref=False, **kws)
+        b3 = gamma * nd + na + naa / beta
+        assert np.allclose(b1 * gamma, b2)
+        assert np.allclose(b2, b3)
 
-        # Test beta and donor_ref arguments with gamma=0.5
-        naa1 = data.get_naa_corrected(gamma=0.5, beta=0.8, donor_ref=True)
-        naa2 = data.get_naa_corrected(gamma=0.5, beta=0.8, donor_ref=False)
-        assert np.allclose(naa1 * 0.5, naa2)
 
 def test_leakage(data):
     """
@@ -443,6 +589,7 @@ def test_leakage(data):
     na2 = list(data.na)
     assert list_array_equal(na1, na2)
 
+
 def test_gamma(data):
     """
     Test setting gamma before and after burst search
@@ -458,6 +605,7 @@ def test_gamma(data):
     E2 = list(data.E)
     assert list_array_equal(E1, E2)
 
+
 def test_dir_ex(data_1ch):
     """
     Test setting dir_ex before and after burst search
@@ -474,6 +622,7 @@ def test_dir_ex(data_1ch):
     na2 = list(data.na)
     assert list_array_equal(na1, na2)
 
+
 def test_beta(data_1ch):
     """
     Test setting beta before and after burst search
@@ -490,6 +639,7 @@ def test_beta(data_1ch):
     S2 = list(data.S)
     assert list_array_equal(S1, S2)
 
+
 def test_bursts_interface(data):
     d = data
     for b in d.mburst:
@@ -506,24 +656,28 @@ def test_bursts_interface(data):
 
         assert (b.stop > b.start).all()
 
+
 def test_burst_stop_istop(data):
     """Test coherence between b_end() and b_iend()"""
     d = data
     for ph, bursts in zip(d.ph_times_m, d.mburst):
         assert (ph[bursts.istop] == bursts.stop).all()
 
+
 def test_monotonic_burst_start(data):
     """Test for monotonic burst start times."""
     d = data
     for i in range(d.nch):
         assert (np.diff(d.mburst[i].start) > 0).all()
 
+
 def test_monotonic_burst_stop(data):
     """Test for monotonic burst stop times."""
     d = data
     for bursts in d.mburst:
         assert (np.diff(bursts.stop) > 0).all()
 
+
 def test_burst_istart_iend_size(data):
     """Test consistency between burst istart, istop and counts (i.e. size)"""
     d = data
@@ -531,6 +685,7 @@ def test_burst_istart_iend_size(data):
         counts = bursts.istop - bursts.istart + 1
         assert (counts == bursts.counts).all()
 
+
 def test_burst_recompute_times(data):
     """Test Bursts.recompute_times method."""
     d = data
@@ -538,6 +693,7 @@ def test_burst_recompute_times(data):
         newbursts = bursts.recompute_times(times)
         assert newbursts == bursts
 
+
 def test_burst_recompute_index(data):
     """Test Bursts.recompute_index_* methods."""
     d = data
@@ -599,6 +755,7 @@ def test_burst_recompute_index(data):
 #        assert  bursts_sel1 == bursts_sel2
 #        assert  bursts_sel == bursts_sel1
 
+
 def test_phrates_mtuple(data):
     d = data
     m = 10
@@ -614,6 +771,7 @@ def test_phrates_mtuple(data):
         assert (rates == (m - 1 - phrates.default_c) / delays).all()
         assert (phrates.mtuple_rates_t(phc, m) == t_rates).all()
 
+
 if has_numba:
     def test_phrates_kde(data):
         d = data
@@ -654,6 +812,7 @@ if has_numba:
             assert (ratesl == rateslc).all()
             assert (ratesr == ratesrc).all()
 
+
 def test_burst_ph_data_functions(data):
     """Tests the functions that iterate or operate on per-burst "ph-data".
     """
@@ -692,6 +851,7 @@ def test_burst_ph_data_functions(data):
                 if i < bistart.size-1 and bistart[i+1] > biend[i] + 1:
                     assert not bursts_mask[stop]
 
+
 def test_ph_in_bursts_ich(data):
     """Tests the ph_in_bursts_ich method.
     """
@@ -701,6 +861,7 @@ def test_ph_in_bursts_ich(data):
         ph_in_bursts_dd = d.ph_in_bursts_ich(ich, ph_sel=Ph_sel(Dex='Dem'))
         assert ph_in_bursts_dd.size < ph_in_bursts.size
 
+
 def test_burst_fuse(data):
     """Test 2 independent implementations of fuse_bursts for consistency.
     """
@@ -710,16 +871,25 @@ def test_burst_fuse(data):
         new_mburstd = bl.fuse_bursts_direct(bursts, ms=1)
         assert new_mbursti == new_mburstd
 
+
 def test_burst_fuse_0ms(data):
     """Test that after fusing with ms=0 the sum of bursts sizes is that same
     as the number of ph in bursts (via burst selection).
     """
     d = data
-
+    if d.nch == 8:
+        d.burst_search(L=10, m=10, F=7, computefret=False)
+        d.mburst[1] = bl.bslib.Bursts.empty()  # Make one channel with no bursts
+        d._calc_burst_period()
+        d.calc_fret(count_ph=True)
     df = d.fuse_bursts(ms=0)
     for ich, bursts in enumerate(df.mburst):
         mask = bl.ph_in_bursts_mask(df.ph_data_sizes[ich], bursts)
         assert mask.sum() == bursts.counts.sum()
+    df.calc_fret(count_ph=True)
+    assert len(df.mburst) == len(d.mburst)
+    assert len(df.mburst) == d.nch
+
 
 def test_burst_fuse_separation(data):
     """Test that after fusing bursts the minimum separation is equal
@@ -729,27 +899,36 @@ def test_burst_fuse_separation(data):
     fuse_ms = 2
     df = d.fuse_bursts(ms=fuse_ms)
     for bursts in df.mburst:
-        separation = bursts.separation*df.clk_p
-        assert separation.min() >= fuse_ms*1e-3
+        separation = bursts.separation * df.clk_p
+        if bursts.num_bursts > 0:
+            assert separation.min() >= fuse_ms * 1e-3
+
 
 def test_calc_sbr(data):
     """Smoke test Data.calc_sbr()"""
     data.calc_sbr()
 
+
 def test_calc_max_rate(data):
     """Smoke test for Data.calc_max_rate()"""
     data.calc_max_rate(m=10)
-    if data.ALEX:
+    if data.alternated:
         data.calc_max_rate(m=10, ph_sel=Ph_sel(Dex='DAem'), compact=True)
 
+
 def test_burst_data(data):
-    """Smoke test for bext.burst_data()"""
+    """Test for bext.burst_data()"""
     bext.burst_data(data, include_bg=True, include_ph_index=True)
+    bext.burst_data(data, include_bg=False, include_ph_index=True)
+    bext.burst_data(data, include_bg=True, include_ph_index=False)
+    bext.burst_data(data, include_bg=False, include_ph_index=False)
+
 
 def test_print_burst_stats(data):
     """Smoke test for burstlib.print_burst_stats()"""
     bl.print_burst_stats(data)
 
+
 def test_expand(data):
     """Test method `expand()` for `Data()`."""
     d = data
@@ -766,6 +945,34 @@ def test_expand(data):
         assert (bg_d == bg_d2).all() and (bg_a == bg_a2).all()
 
 
+def test_burst_data_ich(data):
+    """Test method `Data.burst_data_ich()`."""
+    d = data
+    for ich, bursts in enumerate(d.mburst):
+        if bursts.num_bursts == 0:
+            continue  # if no bursts skip this ch
+        burst_dict = d.burst_data_ich(ich=ich)
+        assert (burst_dict['size_raw'] == bursts.counts).all()
+        assert (burst_dict['t_start'] == bursts.start * d.clk_p).all()
+        assert (burst_dict['t_stop'] == bursts.stop * d.clk_p).all()
+        assert (burst_dict['i_start'] == bursts.istart).all()
+        assert (burst_dict['i_stop'] == bursts.istop).all()
+        assert (burst_dict['bg_period'] == d.bp[ich]).all()
+        nd, na, bg_d, bg_a, width = d.expand(ich, width=True)
+        width_ms = width * 1e3
+        assert (width_ms == burst_dict['width_ms']).all()
+        assert (nd == burst_dict['nd']).all()
+        assert (na == burst_dict['na']).all()
+        assert (bg_d == burst_dict['bg_dd']).all()
+        assert (bg_a == burst_dict['bg_ad']).all()
+        if d.alternated:
+            period = d.bp[ich]
+            bg_da = d.bg_from(Ph_sel(Aex='Dem'))[ich][period] * width
+            bg_aa = d.bg_from(Ph_sel(Aex='Aem'))[ich][period] * width
+            assert (bg_da == burst_dict['bg_da']).all()
+            assert (bg_aa == burst_dict['bg_aa']).all()
+
+
 def test_burst_corrections(data):
     """Test background and bleed-through corrections."""
     d = data
@@ -779,7 +986,7 @@ def test_burst_corrections(data):
         burst_size_raw = bursts.counts
 
         lk = leakage[ich]
-        if d.ALEX:
+        if d.alternated:
             nda, naa = d.nda[ich], d.naa[ich]
             period = d.bp[ich]
             bg_da = d.bg_from(Ph_sel(Aex='Dem'))[ich][period]*width
@@ -791,6 +998,7 @@ def test_burst_corrections(data):
             burst_size_raw2 = nd + na + bg_d + bg_a + lk*nd
             assert np.allclose(burst_size_raw, burst_size_raw2)
 
+
 def test_burst_search_consistency(data):
     """Test consistency of burst data array
     """
@@ -816,6 +1024,7 @@ def test_burst_search_consistency(data):
         start, stop, width = mb.start, mb.stop, mb.width
         assert np.all(width <= stop - start)
 
+
 def test_E_and_S_with_corrections(data):
     d = data
     gamma = 0.5
@@ -824,8 +1033,10 @@ def test_E_and_S_with_corrections(data):
     d.beta = beta
     for i, (E, nd, na) in enumerate(zip(d.E, d.nd, d.na)):
         assert (E == na / (nd * gamma + na)).all()
-        if d.ALEX:
+        if d.alternated:
             naa = d.naa[i]
+            if 'PAX' in data.meas_type:
+                naa = d.naa[i] - d.nar[i]
             assert (d.S[i] == (gamma * nd + na) /
                               (gamma * nd + na + naa / beta)).all()
 
@@ -835,7 +1046,7 @@ def test_burst_size_da(data):
     """
     d = data
     d.calc_ph_num(alex_all=True)
-    if d.ALEX:
+    if d.alternated:
         for mb, nd, na, naa, nda in zip(d.mburst, d.nd, d.na, d.naa, d.nda):
             tot_size = mb.counts
             tot_size2 = nd + na + naa + nda
@@ -845,6 +1056,7 @@ def test_burst_size_da(data):
             tot_size = mb.counts
             assert (tot_size == nd + na).all()
 
+
 def test_burst_selection(data):
     """Smoke test for burst selection methods.
     """
@@ -861,6 +1073,7 @@ def test_burst_selection(data):
     Mb2 = [m1 + m2 for m1, m2 in zip(M1, M2)]
     assert list_array_equal(Mb, Mb2)
 
+
 def test_burst_selection_nocorrections(data):
     """Test burst selection with uncorrected bursts.
     """
@@ -876,10 +1089,11 @@ def test_burst_selection_nocorrections(data):
     assert list_array_equal(ds1.nd, ds2.nd)
     assert list_array_equal(ds1.na, ds2.na)
     assert list_array_equal(ds1.E, ds2.E)
-    if d.ALEX:
+    if d.alternated:
         assert list_array_equal(ds1.naa, ds2.naa)
         assert list_array_equal(ds1.E, ds2.E)
 
+
 def test_burst_selection_ranges(data):
     """Test selection functions having a min-max range.
     """
@@ -894,7 +1108,7 @@ def test_burst_selection_ranges(data):
         time=Range(1, 61, lambda d, ich: d.mburst[ich].start * d.clk_p),
         width=Range(0.5, 1.5, lambda d, ich: d.mburst[ich].width * d.clk_p*1e3),
         peak_phrate=Range(50e3, 150e3, lambda d, ich: d.max_rate[ich]))
-    if d.ALEX:
+    if d.alternated:
         sel_functions.update(naa=Range(30, 40, None), S=Range(0.3, 0.7, None))
 
     for func_name, range_ in sel_functions.items():
@@ -908,6 +1122,7 @@ def test_burst_selection_ranges(data):
             selected = getter(ds, ich)
             assert ((selected >= range_.min) * (selected <= range_.max)).all()
 
+
 def test_join_data(data):
     """Smoke test for bext.join_data() function.
     """
@@ -917,6 +1132,7 @@ def test_join_data(data):
     for bursts in dj.mburst:
         assert (np.diff(bursts.start) > 0).all()
 
+
 def test_collapse(data_8ch):
     """Test the .collapse() method that joins the ch.
     """
